@@ -2,7 +2,7 @@
  * \brief System specific definitions, not for installation!
  */
 /*
- * Copyright (C) 2007 Hans Ulrich Niedermann <gp@n-dimensional.de>
+ * Copyright (c) 2007 Hans Ulrich Niedermann <gp@n-dimensional.de>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -16,12 +16,12 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA.
  */
 
-#ifndef EXIF_SYSTEM_H
-#define EXIF_SYSTEM_H
+#ifndef LIBEXIF_EXIF_SYSTEM_H
+#define LIBEXIF_EXIF_SYSTEM_H
 
 #if defined(__GNUC__) && (__GNUC__ >= 2)
 # define UNUSED(param) UNUSED_PARAM_##param __attribute__((unused))
@@ -29,4 +29,4 @@
 # define UNUSED(param) param
 #endif
 
-#endif /* !defined(EXIF_SYSTEM_H) */
+#endif /* !defined(LIBEXIF_EXIF_SYSTEM_H) */
