@@ -18,8 +18,8 @@
  * Boston, MA  02110-1301  USA.
  */
 
-#ifndef __MNOTE_FUJI_ENTRY_H__
-#define __MNOTE_FUJI_ENTRY_H__
+#ifndef LIBEXIF_MNOTE_FUJI_ENTRY_H
+#define LIBEXIF_MNOTE_FUJI_ENTRY_H
 
 #include <libexif/exif-format.h>
 #include <libexif/fuji/mnote-fuji-tag.h>
@@ -42,4 +42,4 @@ struct _MnoteFujiEntry {
 
 char *mnote_fuji_entry_get_value (MnoteFujiEntry *entry, char *val, unsigned int maxlen);
 
-#endif /* __MNOTE_FUJI_ENTRY_H__ */
+#endif /* !defined(LIBEXIF_MNOTE_FUJI_ENTRY_H) */
